package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Jul 13, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Field struct {
Terms []Term
Values []int
}
const (
KindStar Kind = iota
KindSingle
KindRange
KindStep
)
type Term struct {
Kind Kind
Start, End, Step int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.